API docs for “spamfighter.core.test.test_null_partner.NullPartnerAuthorizerTestCase”

# Class s.c.t.t.NullPartnerAuthorizerTestCase(unittest.TestCase):

Part of spamfighter.core.test.test_null_partner View Source View In Hierarchy

Тест на `spamfighter.core.null_partner.NullPartnerAuthorizer`.

Method | testInterface | Undocumented
Method | testAuthorizeFailure | Undocumented
Method | testAuthorizeOk | Undocumented

def testInterface(self): (source)
Undocumented
def testAuthorizeFailure(self): (source)
Undocumented
def testAuthorizeOk(self): (source)
Undocumented